# Pydre Overview

Pydre is a software package designed to analyze driving data taken from driving simulation research studies. Specifically, it was built around the data file format generated by [SimObserver](https://www.faac.com/realtime-technologies/products/simobserver-pro/), which is software sold by Realtime Technologies for recording data from their SimCreator simulation system.

# Documentation

Full documentation can be found on [GitHub pages](https://osudsl.github.io/pydre/)

# Credits

Pydre was developed by The Ohio State University [Driving Simulation Lab](https://drivesim.osu.edu/).

